Documentation
¶
Index ¶
- func Build(img OCIImage, buildkitd *Buildkitd, outputsDir string) error
- func BuildConfig(img OCIImage) prototype.Config
- func Prototype() prototype.Prototype
- func RunBuild(img OCIImage) ([]prototype.MessageResponse, error)
- func ServeRegistry(reg LocalRegistry) (string, error)
- type Buildkitd
- type BuildkitdConfig
- type BuildkitdOpts
- type ImageMetadata
- type LocalRegistry
- type OCIImage
- type RegistryConfig
- type TLSConfig
- type TLSKeyPair
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BuildConfig ¶
func ServeRegistry ¶
func ServeRegistry(reg LocalRegistry) (string, error)
Types ¶
type Buildkitd ¶
type Buildkitd struct {
Addr string
// contains filtered or unexported fields
}
func SpawnBuildkitd ¶
func SpawnBuildkitd(ociImage OCIImage, opts *BuildkitdOpts) (*Buildkitd, error)
type BuildkitdConfig ¶
type BuildkitdConfig struct {
Registries map[string]RegistryConfig `toml:"registry"`
}
type BuildkitdOpts ¶
BuildkitdOpts to provide to Buildkitd
type ImageMetadata ¶
ImageMetadata is the schema written to manifest.json when producing the legacy Concourse image format (rootfs/..., metadata.json).
type LocalRegistry ¶
func LoadRegistry ¶
func LoadRegistry(imagePaths map[string]string) (LocalRegistry, error)
func (LocalRegistry) BuildArgs ¶
func (registry LocalRegistry) BuildArgs(port string) []string
func (LocalRegistry) GetBlob ¶
func (registry LocalRegistry) GetBlob(w http.ResponseWriter, r *http.Request, p httprouter.Params)
func (LocalRegistry) GetManifest ¶
func (registry LocalRegistry) GetManifest(w http.ResponseWriter, r *http.Request, p httprouter.Params)
type OCIImage ¶
type OCIImage struct {
Debug bool `json:"debug"`
ContextDir string `json:"context" prototype:"required"`
ContextInputs map[string]string `json:"context_inputs,omitempty"`
DockerfilePath string `json:"dockerfile,omitempty"`
Output string `json:"output" prototype:"required"`
Cache bool `json:"cache,omitempty"`
Target string `json:"target"`
AdditionalTargets []string `json:"additional_targets"`
BuildArgs []string `json:"build_args"`
RegistryMirrors []string `json:"registry_mirrors"`
Labels []string `json:"labels"`
BuildkitSecrets map[string]string `json:"buildkit_secrets"`
// Unpack the OCI image into Concourse's rootfs/ + metadata.json image scheme.
//
// Theoretically this would go away if/when we standardize on OCI.
UnpackRootfs bool `json:"unpack_rootfs"`
// Images to pre-load in order to avoid fetching at build time. Mapping from
// build arg name to OCI image tarball path.
//
// Each image will be pre-loaded and a build arg will be set to a value
// appropriate for setting in 'FROM ...'.
ImageArgs []string `json:"image_args"`
AddHosts string `json:"add_hosts"`
}
OCIImage is the object being acted upon by the prototype.
type RegistryConfig ¶
type TLSKeyPair ¶
Source Files
¶
Click to show internal directories.
Click to hide internal directories.